@@ -35,10 +35,12 @@ class Bitpin:
         self.__access_token = None
         self.__refresh_token = None
 
-        self.__handle_access_token()
+        self.__headers = {
+            'Content-Type': 'application/json',
+            'Accept': 'application/json',
+        }
 
         self.__base_url = 'https://api.bitpin.ir'
-        self.__requests_params = requests_params
 
         # set timeout from requests_params
         if requests_params is not None:
@@ -48,10 +50,7 @@ class Bitpin:
             self.__timeout = 10
             self.__verify = True
 
-        self.__headers = {
-            'Content-Type': 'application/json',
-            'Accept': 'application/json',
-        }
+        self.__handle_access_token()
 
         return
 
@@ -61,7 +60,7 @@ class Bitpin:
         """
 
         if self.api_key is not None and self.api_secret is not None:
-            login = self.login()
+            login = self.login(self.api_key, self.api_secret)
             self.__access_token = login['access_token']
             self.__refresh_token = login['refresh_token']
 
@@ -294,7 +293,7 @@ class Bitpin:
 
         self.__access_token = token
 
-    def login(self) -> t.Dict:
+    def login(self, api_key: str, secret_key: str) -> t.Dict:
         """
         Get token.
 
@@ -307,11 +306,17 @@ class Bitpin:
 
         url = '/v1/usr/api/login/'
 
+        json_data = {
+            'api_key': api_key,
+            'secret_key': secret_key,
+        }
+
         response = self._request(
             f_name,
             'POST',
             url,
             auth=False,
+            json_data=json_data
         )
 
         return self._process_response(f_name, response, f_args)
